@@ -40,9 +40,7 @@ class ApiKeyAuthPlugin:
 
     def __call__(self, handler):
         def wrapped_handler(*args, **kwargs):
-            print(f'headers: {dict(request.headers)}')
             auth_header = request.headers.get('Authorization', '')
-            print(f'Expected {self._api_key}, got {auth_header}')
             if auth_header == self._api_key:
                 return handler(*args, **kwargs)
             response.status = 401
@@ -53,14 +51,14 @@ class ApiKeyAuthPlugin:
 
 # from https://stackoverflow.com/questions/17262170/bottle-py-enabling-cors-for-jquery-ajax-requests
 class CorsPlugin:
-    def __init(self, origins: str = '*'):
+    def __init__(self, origins: str = '*'):
         self._origins = origins
 
     def __call__(self, handler):
         def wrapped_handler(*args, **kwargs):
             response.headers['Access-Control-Allow-Origin'] = self._origins
             response.headers['Access-Control-Allow-Methods'] = 'GET, POST, PUT, OPTIONS'
-            response.headers['Access-Control-Allow-Headers'] = 'Origin, Accept, Content-Type, X-Requested-With, X-CSRF-Token'
+            response.headers['Access-Control-Allow-Headers'] = 'Origin, Accept, Content-Type, X-Requested-With, X-api-key',
             if request.method != OPTIONS:
                 return handler(*args, **kwargs)
         return wrapped_handler
